==> qt-x11-free-3.1.2.tar.bz2: qt-x11-free-3.1.2/src/sql/qsql.h <==
/****************************************************************************
**
** Definition of QSql class
**
** Created : 2000-11-03
**
** Copyright (C) 2000 Trolltech AS.  All rights reserved.
**
** This file is part of the sql module of the Qt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
** LICENSE.QPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition licenses may use this
** file in accordance with the Qt Commercial License Agreement provided
** with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
** See http://www.trolltech.com/qpl/ for QPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef QSQL_H
#define QSQL_H

#ifndef QT_H
#include "qglobal.h"
#endif // QT_H

#if !defined( QT_MODULE_SQL ) || defined( QT_LICENSE_PROFESSIONAL )
#define QM_EXPORT_SQL
#else
#define QM_EXPORT_SQL Q_EXPORT
#endif

#ifndef QT_NO_SQL

class QM_EXPORT_SQL QSql
{
public:
    QSql() {}
    enum Op {
	None = -1,
	Insert = 0,
	Update = 1,
	Delete = 2
    };

    enum Location {
	BeforeFirst = -1,
	AfterLast = -2
    };

    enum Confirm {
	Cancel = -1,
	No = 0,
	Yes = 1
    };

#ifndef Q_QDOC
    enum ParameterType {
	In,
	Out,
	InOut
    };
#endif

private:	// Disabled copy constructor and operator=
#if defined(Q_DISABLE_COPY)
    QSql( const QSql & );
    QSql &operator=( const QSql & );
#endif

};

#endif
#endif

==> qt-x11-free-3.3.6.tar.bz2: qt-x11-free-3.3.6/src/sql/qsql.h <==
/****************************************************************************
**
** Definition of QSql class
**
** Created : 2000-11-03
**
** Copyright (C) 2005 Trolltech AS.  All rights reserved.
**
** This file is part of the sql module of the Qt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
** LICENSE.QPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition licenses may use this
** file in accordance with the Qt Commercial License Agreement provided
** with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
** See http://www.trolltech.com/qpl/ for QPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef QSQL_H
#define QSQL_H

#ifndef QT_H
#include "qglobal.h"
#endif // QT_H

#if !defined( QT_MODULE_SQL ) || defined( QT_LICENSE_PROFESSIONAL )
#define QM_EXPORT_SQL
#else
#define QM_EXPORT_SQL Q_EXPORT
#endif

#ifndef QT_NO_SQL

class QM_EXPORT_SQL QSql
{
public:
    QSql() {}
    enum Op {
	None = -1,
	Insert = 0,
	Update = 1,
	Delete = 2
    };

    enum Location {
	BeforeFirst = -1,
	AfterLast = -2
    };

    enum Confirm {
	Cancel = -1,
	No = 0,
	Yes = 1
    };

    enum ParameterType {
	In = 1,
	Out = 2,
	InOut = 3  //InOut = In | Out
    };

    enum TableType { 
	Tables = 0x01,
	SystemTables = 0x02,
	Views = 0x04,
	AllTables = 0xff
    };

private:	// Disabled copy constructor and operator=
#if defined(Q_DISABLE_COPY)
    QSql( const QSql & );
    QSql &operator=( const QSql & );
#endif

};

#endif
#endif
